Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(262)

Unified Diff: pkg/analyzer/tool/summary/idl.dart

Issue 1648783002: Repalce shiftOr with pushLongInt, tweak makeSymbol. (Closed) Base URL: git@github.com:dart-lang/sdk.git@master
Patch Set: Created 4 years, 11 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « pkg/analyzer/test/src/summary/summary_common.dart ('k') | no next file » | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: pkg/analyzer/tool/summary/idl.dart
diff --git a/pkg/analyzer/tool/summary/idl.dart b/pkg/analyzer/tool/summary/idl.dart
index cb2ee1d5e2a8a94c32850a16190a733377da995d..2237d04a82e60df7eba9df418cf39e7e6d4c4d45 100644
--- a/pkg/analyzer/tool/summary/idl.dart
+++ b/pkg/analyzer/tool/summary/idl.dart
@@ -510,17 +510,17 @@ enum UnlinkedConstOperation {
* onto the stack.
*
* Note that Dart supports integers larger than 32 bits; these are
* represented by composing 32 bit values using the [shiftOr] operation.
*/
pushInt,
/**
- * Pop the top value off the stack, which should be an integer. Multiply it
- * by 2^32, "or" in the next value from [UnlinkedConst.ints] (which is
- * interpreted as a 32-bit unsigned integer), and push the result back onto
- * the stack.
+ * Get the number of components from [UnlinkedConst.ints], then do this number
+ * of times the following operations: multiple the current value by 2^32, "or"
+ * it with the next value in [UnlinkedConst.ints]. The initial value is zero.
+ * Push the result into the stack.
*/
- shiftOr,
+ pushLongInt,
/**
* Push the next value from [UnlinkedConst.doubles] (a double precision
@@ -554,8 +554,8 @@ enum UnlinkedConstOperation {
concatenate,
/**
- * Pop the top value from the stack which should be string, convert it to
- * a symbol, and push it back onto the stack.
+ * Get the next value from [UnlinkedConst.strings], convert it to a symbol,
+ * and push it onto the stack.
*/
makeSymbol,
« no previous file with comments | « pkg/analyzer/test/src/summary/summary_common.dart ('k') | no next file » | no next file with comments »
@@ -510,17 +510,17 @@ enum UnlinkedConstOperation {
*
* Note that Dart supports integers larger than 32 bits; these are
- * represented by composing 32 bit values using the [shiftOr] operation.
+ * represented by composing 32-bit values using the [pushLongInt] operation.
*/
pushInt,

Powered by Google App Engine
This is Rietveld 408576698